﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.Wpf;

namespace _9535
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void map_Loaded(object sender, RoutedEventArgs e)
        {
            map.MapUnit = GeographyUnit.Meter;

            LayerOverlay layerOverlay = new LayerOverlay();
            InMemoryFeatureLayer layer1 = new InMemoryFeatureLayer();
            layer1.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = new CustomPointStyle(new GeoSolidBrush(GeoColors.Black), new GeoPen(GeoColors.Black), 15);
            layer1.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            layer1.InternalFeatures.Add(new Feature(10, 10));

            layerOverlay.Layers.Add(layer1);
            map.Overlays.Add(layerOverlay);

            layer1.Open();
            map.CurrentExtent = layer1.GetBoundingBox();
            map.Refresh();
        }
    }

    public class CustomPointStyle : PointStyle
    {
        GeoSolidBrush fillBrush;
        GeoPen outerlinePen;
        int symbolSize;

        public CustomPointStyle(GeoSolidBrush fillBrush, GeoPen outerlinePen, int symbolSize) : base(PointSymbolType.Circle, fillBrush, outerlinePen, symbolSize)
        {
            this.fillBrush = fillBrush;
            this.outerlinePen = outerlinePen;
            this.symbolSize = symbolSize;
        }

        protected override void DrawCore(IEnumerable<Feature> features, GeoCanvas canvas, Collection<SimpleCandidate> labelsInThisLayer, Collection<SimpleCandidate> labelsInAllLayers)
        {
            foreach (Feature feature in features)
            {
                Feature f = feature.CloneDeep();
                Feature round = f.Buffer(20, GeographyUnit.Meter, DistanceUnit.Meter);

                // Draw the circle by base style
                canvas.DrawEllipse(feature, SymbolSize, SymbolSize, outerlinePen, fillBrush, DrawingLevel, XOffsetInPixel, YOffsetInPixel, PenBrushDrawingOrder.BrushFirst);


                // Add your logic to draw custom style
                canvas.DrawEllipse(feature, SymbolSize + 10, SymbolSize + 10, new GeoPen(GeoColors.Red, 6), new GeoSolidBrush(GeoColors.Transparent), DrawingLevel, XOffsetInPixel, YOffsetInPixel, PenBrushDrawingOrder.BrushFirst);
            }

            //base.DrawCore(features, canvas, labelsInThisLayer, labelsInAllLayers);
        }
    }

}
